@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -10,6 +10,7 @@
 #include "associationwidget.h"
 #include "classifier.h"
 #include "cmds.h"
+#define DBG_SRC QLatin1String("UMLDragData")
 #include "debug_utils.h"
 #include "floatingtextwidget.h"
 #include "folder.h"
@@ -36,6 +37,8 @@
 #include <QTextStream>
 #include <QXmlStreamWriter>
 
+DEBUG_REGISTER(UMLDragData)
+
 /**
  *  Constructor.
  */
@@ -123,7 +126,7 @@ void UMLDragData::setUMLDataClip1(UMLObjectList& objects)
     UMLObject* obj = 0;
     while (object_it.hasNext()) {
         obj = object_it.next();
-        obj->saveToXMI1(stream);
+        obj->saveToXMI(stream);
     }
 
     stream.writeEndElement();  // umlobjects
@@ -146,14 +149,14 @@ void UMLDragData::setUMLDataClip2(UMLObjectList& objects, UMLViewList& diagrams)
     UMLObject* obj = 0;
     while (object_it.hasNext()) {
         obj = object_it.next();
-        obj->saveToXMI1(stream);
+        obj->saveToXMI(stream);
     }
 
     stream.writeEndElement();  // umlobjects
     stream.writeStartElement(QLatin1String("umlviews"));
 
     foreach(UMLView* view, diagrams) {
-        view->umlScene()->saveToXMI1(stream);
+        view->umlScene()->saveToXMI(stream);
     }
 
     stream.writeEndElement();  // umlviews
@@ -173,7 +176,7 @@ void UMLDragData::setUMLDataClip3(UMLListViewItemList& umlListViewItems)
     stream.writeStartElement(QLatin1String("umllistviewitems"));
 
     foreach(UMLListViewItem* item, umlListViewItems) {
-        item->saveToXMI1(stream);
+        item->saveToXMI(stream);
     }
 
     stream.writeEndElement();  // umllistviewitems
@@ -200,21 +203,21 @@ void UMLDragData::setUMLDataClip4(UMLObjectList& objects,
     stream.writeStartElement(QLatin1String("umlobjects"));
 
     foreach (UMLObject* obj, objects) {
-        obj->saveToXMI1(stream);
+        obj->saveToXMI(stream);
     }
 
     stream.writeEndElement();  // umlobjects
     stream.writeStartElement(QLatin1String("widgets"));
 
     foreach (UMLWidget* widget, widgets) {
-        widget->saveToXMI1(stream);
+        widget->saveToXMI(stream);
     }
 
     stream.writeEndElement();  // widgets
     stream.writeStartElement(QLatin1String("associations"));
 
     foreach (AssociationWidget* association, associations) {
-        association->saveToXMI1(stream);
+        association->saveToXMI(stream);
     }
 
     stream.writeEndElement();  // associations
@@ -243,7 +246,7 @@ void UMLDragData::setUMLDataClip5(UMLObjectList& objects)
     stream.writeStartElement(QLatin1String("umlobjects"));
 
     foreach (UMLObject* obj, objects) {
-        obj->saveToXMI1(stream);
+        obj->saveToXMI(stream);
     }
 
     stream.writeEndElement();  // umlobjects
@@ -272,7 +275,7 @@ bool UMLDragData::decodeClip1(const QMimeData* mimeData, UMLObjectList& objects)
     int line;
     QDomDocument domDoc;
     if(!domDoc.setContent(xmiClip, false, &error, &line)) {
-        uWarning() << "Cannot set content:" << error << " Line:" << line;
+        logWarn2("UMLDragData::getClip3TypeAndID: Cannot set content. Error %1 line %2", error, line);
         return false;
     }
     QDomNode xmiClipNode = domDoc.firstChild();
@@ -313,7 +316,7 @@ bool UMLDragData::decodeClip2(const QMimeData* mimeData, UMLObjectList& objects,
     int line;
     QDomDocument domDoc;
     if(!domDoc.setContent(xmiClip, false, &error, &line)) {
-        uWarning() << "Cannot set content:" << error << " Line:" << line;
+        logWarn2("UMLDragData::decodeClip2: Cannot set content. Error %1 line %2", error, line);
         return false;
     }
     QDomNode xmiClipNode = domDoc.firstChild();
@@ -367,7 +370,7 @@ bool UMLDragData::getClip3TypeAndID(const QMimeData* mimeData,
     int line;
     QDomDocument domDoc;
     if(!domDoc.setContent(xmiClip, false, &error, &line)) {
-        uWarning() << "getClip3Type: Cannot set content:" << error << " Line:" << line;
+        logWarn2("UMLDragData::getClip3TypeAndID: Cannot set content. Error %1 line %2", error, line);
         return false;
     }
     QDomNode xmiClipNode = domDoc.firstChild();
@@ -384,18 +387,18 @@ bool UMLDragData::getClip3TypeAndID(const QMimeData* mimeData,
     QDomNode listItems = listItemNode.firstChild();
     QDomElement listItemElement = listItems.toElement();
     if (listItemElement.isNull()) {
-        uWarning() << "getClip3Type: No listitems in XMI clip.";
+        logWarn0("UMLDragData::getClip3TypeAndID: No listitems in XMI clip.");
         return false;
     }
     while (!listItemElement.isNull()) {
         QString typeStr = listItemElement.attribute(QLatin1String("type"), QLatin1String("-1"));
         if (typeStr == QLatin1String("-1")) {
-            uDebug() << "getClip3Type: bad type.";
+            logDebug0("UMLDragData::getClip3TypeAndID: bad type.");
             return false;
         }
         QString idStr = listItemElement.attribute(QLatin1String("id"), QLatin1String("-1"));
         if (idStr == QLatin1String("-1")) {
-            uDebug() << "getClip3Type: bad id";
+            logDebug0("UMLDragData::getClip3TypeAndID: bad id");
             return false;
         }
         LvTypeAndID * pData = new LvTypeAndID;
@@ -429,7 +432,7 @@ bool UMLDragData::decodeClip3(const QMimeData* mimeData, UMLListViewItemList& um
     int line;
     QDomDocument domDoc;
     if(!domDoc.setContent(xmiClip, false, &error, &line)) {
-        uWarning() << "Cannot set content:" << error << " Line:" << line;
+        logWarn2("UMLDragData::decodeClip3: Cannot set content. Error %1 line %2", error, line);
         return false;
     }
     QDomNode xmiClipNode = domDoc.firstChild();
@@ -447,7 +450,7 @@ bool UMLDragData::decodeClip3(const QMimeData* mimeData, UMLListViewItemList& um
     QDomNode listItems = listItemNode.firstChild();
     QDomElement listItemElement = listItems.toElement();
     if (listItemElement.isNull()) {
-        uWarning() << "no listitems in XMI clip";
+        logWarn0("UMLDragData::decodeClip3: no listitems in XMI clip");
         return false;
     }
     while (!listItemElement.isNull()) {
@@ -455,7 +458,7 @@ bool UMLDragData::decodeClip3(const QMimeData* mimeData, UMLListViewItemList& um
         // UMLListViewItem instance.
         QString type = listItemElement.attribute(QLatin1String("type"), QLatin1String("-1"));
         if (type == QLatin1String("-1")) {
-            uDebug() << "Type not found.";
+            logDebug0("UMLDragData::decodeClip3: Type not found.");
             listItems = listItems.nextSibling();
             listItemElement = listItems.toElement();
             continue;
@@ -463,7 +466,7 @@ bool UMLDragData::decodeClip3(const QMimeData* mimeData, UMLListViewItemList& um
         UMLListViewItem::ListViewType t = (UMLListViewItem::ListViewType)(type.toInt());
         UMLListViewItem* parent = parentListView->determineParentItem(t);
         UMLListViewItem* itemData = new UMLListViewItem(parent);
-        if (itemData->loadFromXMI1(listItemElement))
+        if (itemData->loadFromXMI(listItemElement))
             umlListViewItems.append(itemData);
         else
             delete itemData;
@@ -498,7 +501,7 @@ bool UMLDragData::decodeClip4(const QMimeData* mimeData, UMLObjectList& objects,
     int line;
     QDomDocument domDoc;
     if(!domDoc.setContent(xmiClip, false, &error, &line)) {
-        uWarning() << "Cannot set content:" << error << " Line:" << line;
+        logWarn2("UMLDragData::decodeClip4: Cannot set content. Error %1 line %2", error, line);
         return false;
     }
     QDomNode xmiClipNode = domDoc.firstChild();
@@ -537,7 +540,7 @@ bool UMLDragData::decodeClip4(const QMimeData* mimeData, UMLObjectList& objects,
     QDomNode widgetNode = widgetsNode.firstChild();
     QDomElement widgetElement = widgetNode.toElement();
     if (widgetElement.isNull()) {
-        uWarning() << "No widgets in XMI clip.";
+        logWarn0("UMLDragData::decodeClip4: No widgets in XMI clip.");
         return false;
     }
 
@@ -600,7 +603,7 @@ bool UMLDragData::decodeClip4(const QMimeData* mimeData, UMLObjectList& objects,
             // UMLClipboard
             widgets.append(widget);
         } else {
-            uWarning() << "Unable to paste widget" << widgetElement.tagName();
+            logWarn1("UMLDragData::decodeClip4: Unable to paste widget %1", widgetElement.tagName());
         }
 
         widgetNode = widgetNode.nextSibling();
@@ -645,7 +648,7 @@ bool UMLDragData::decodeClip4(const QMimeData* mimeData, UMLObjectList& objects,
     QDomElement associationWidgetElement = associationWidgetNode.toElement();
     while (!associationWidgetElement.isNull()) {
         AssociationWidget* associationWidget = AssociationWidget::create(view->umlScene());
-        if (associationWidget->loadFromXMI1(associationWidgetElement, widgets, 0))
+        if (associationWidget->loadFromXMI(associationWidgetElement, widgets, 0))
             associations.append(associationWidget);
         else {
             delete associationWidget;
@@ -678,7 +681,7 @@ bool UMLDragData::decodeClip5(const QMimeData* mimeData, UMLObjectList& objects,
     int line;
     QDomDocument domDoc;
     if(!domDoc.setContent(xmiClip, false, &error, &line)) {
-        uWarning() << "Cannot set content:" << error << " Line:" << line;
+        logWarn2("UMLDragData::decodeClip5: Cannot set content. Error %1 line %2", error, line);
         return false;
     }
     QDomNode xmiClipNode = domDoc.firstChild();
@@ -702,11 +705,11 @@ bool UMLDragData::decodeClip5(const QMimeData* mimeData, UMLObjectList& objects,
         QString type = element.tagName();
         UMLClassifierListItem *pObject = newParent->makeChildObject(type);
         if(!pObject) {
-            uWarning() << "Given wrong type of umlobject to create:" << type;
+            logWarn1("UMLDragData::decodeClip5 given wrong type of umlobject to create: %1", type);
             return false;
         }
-        if(!pObject->loadFromXMI1(element)) {
-            uWarning() << "Failed to load object from XMI.";
+        if(!pObject->loadFromXMI(element)) {
+            logWarn0("UMLDragData::decodeClip5 failed to load object from XMI.");
             return false;
         }
         pObject->resolveRef();
@@ -741,7 +744,7 @@ bool UMLDragData::decodeObjects(QDomNode& objectsNode, UMLObjectList& objects, b
     while (!element.isNull()) {
         pObject = 0;
         QString type = element.tagName();
-        Uml::ID::Type elmId = Uml::ID::fromString(element.attribute(QLatin1String("xmi.id")));
+        Uml::ID::Type elmId = Uml::ID::fromString(Model_Utils::getXmiId(element));
         QString stereotype = element.attribute(QLatin1String("stereotype"));
 
         bool objectExists = (doc->findObjectById(elmId) != 0);
@@ -762,7 +765,7 @@ bool UMLDragData::decodeObjects(QDomNode& objectsNode, UMLObjectList& objects, b
             type == QLatin1String("UML:Interface") ||
             type == QLatin1String("UML:Component")) {
             QDomNodeList list = element.childNodes();
-            for (int i=(list.length() - 1); i>=0; i--) {
+            for (int i = list.length() - 1; i >= 0; i--) {
                 QDomNode child = list.at(i);
                 QString tagName = child.toElement().tagName();
                 if (tagName == QLatin1String("UML:Namespace.ownedElement") ||
@@ -774,7 +777,7 @@ bool UMLDragData::decodeObjects(QDomNode& objectsNode, UMLObjectList& objects, b
 
         pObject = Object_Factory::makeObjectFromXMI(type, stereotype);
         if(!pObject) {
-            uWarning() << "Given wrong type of umlobject to create: " << type;
+            logWarn1("UMLDragData::decodeObjects given wrong type of umlobject to create: %1", type);
             return false;
         }
 
@@ -804,10 +807,10 @@ bool UMLDragData::decodeObjects(QDomNode& objectsNode, UMLObjectList& objects, b
 
         pObject->setUMLPackage(newParent);
 
-        // Note: element should not be used after calling loadFromXMI1() because
+        // Note: element should not be used after calling loadFromXMI() because
         // it can point to an arbitrary child node
-        if(!pObject->loadFromXMI1(element)) {
-            uWarning() << "Failed to load object of type " << type << " from XMI";
+        if (!pObject->loadFromXMI(element)) {
+            logWarn1("UMLDragData::decodeObjects failed to load object of type %1 from XMI", type);
             delete pObject;
             return false;
         }
@@ -839,7 +842,7 @@ bool UMLDragData::decodeViews(QDomNode& umlviewsNode, UMLViewList& diagrams)
     QDomNode diagramNode = umlviewsNode.firstChild();
     QDomElement diagramElement = diagramNode.toElement();
     if (diagramElement.isNull()) {
-        uWarning() << "No diagrams in XMI clip.";
+        logWarn0("UMLDragData::decodeViews: No diagrams in XMI clip.");
         return false;
     }
     UMLListView *listView = UMLApp::app()->listView();
@@ -848,7 +851,7 @@ bool UMLDragData::decodeViews(QDomNode& umlviewsNode, UMLViewList& diagrams)
             QString idStr = diagramElement.attribute(QLatin1String("xmi.id"), QLatin1String("-1"));
             Uml::ID::Type id = Uml::ID::fromString(idStr);
             if (id == Uml::ID::None) {
-                uDebug() << "Cannot paste diagram hyperlink to note because decoding of xmi.id failed";
+                logDebug0("UMLDragData::decodeViews: Cannot paste diagram hyperlink to note because decoding of xmi.id failed");
                 return false;
             }
             NoteWidget::s_pCurrentNote->setDiagramLink(id);
@@ -861,12 +864,12 @@ bool UMLDragData::decodeViews(QDomNode& umlviewsNode, UMLViewList& diagrams)
             return false;
         UMLObject *po = parent->umlObject();
         if (po == 0 || po->baseType() != UMLObject::ot_Folder) {
-            uError() << "Bad parent for view.";
+            logError0("UMLDragData::decodeViews: Bad parent for view.");
             return false;
         }
         UMLFolder *f = po->asUMLFolder();
         UMLView* view = new UMLView(f);
-        view->umlScene()->loadFromXMI1(diagramElement);
+        view->umlScene()->loadFromXMI(diagramElement);
         diagrams.append(view);
         diagramNode = diagramNode.nextSibling();
         diagramElement = diagramNode.toElement();
