@@ -3,7 +3,7 @@
 
     SPDX-FileCopyrightText: 2003 Brian Thomas
     <brian.thomas@gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors
     <umbrello-devel@kde.org>
 */
 
@@ -93,7 +93,7 @@ CPPCodeGenerationPolicy *CppWriter::policyExt()
 void CppWriter::writeClass(UMLClassifier *c)
 {
     if (!c) {
-        uDebug() << "Cannot write class of NULL concept!";
+        logWarn0("CppWriter::writeClass: Cannot write class of NULL concept!");
         return;
     }
 
@@ -1142,7 +1142,7 @@ void CppWriter::writeConstructorMethods(UMLClassifier * c, QTextStream &stream)
  * Write all datatypes for a given class.
  * @param c                the class for which we are generating code
  * @param permitScope      what type of method to write (by Scope)
- * @param cpp              the stream associated with the output file
+ * @param stream           QTextStream serialization target
  */
 void CppWriter::writeDataTypes(UMLClassifier *c, Uml::Visibility::Enum permitScope, QTextStream &stream)
 {
@@ -1152,7 +1152,7 @@ void CppWriter::writeDataTypes(UMLClassifier *c, Uml::Visibility::Enum permitSco
             continue;
         if (!o->isUMLDatatype())
             continue;
-        UMLDatatype *d = o->asUMLDatatype();
+        const UMLDatatype *d = o->asUMLDatatype();
         if (d && d->isReference() && d->originType()) {
             stream << indent() << "typedef " << d->originType()->name() << " " << d->name() << ";" << m_endl;
         }
