@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2005-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2005-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -11,6 +11,7 @@
 #include "kdevcppparser/cpptree2uml.h"
 
 // app includes
+#define DBG_SRC QLatin1String("CppImport")
 #include "debug_utils.h"
 #include "import_utils.h"
 #include "uml.h"
@@ -42,6 +43,8 @@ public:
     }
 };
 
+DEBUG_REGISTER(CppImport)
+
 /**
  * Constructor.
  */
@@ -78,10 +81,10 @@ void CppImport::feedTheModel(const QString& fileName)
                 continue;
             QString includeFile = it.key();
             if (includeFile.isEmpty()) {
-                uError() << fileName << ": " << it.value().first << " not found";
+                logError2("CppImport::feedTheModel(%1) : %2 not found", fileName, it.value().first);
                 continue;
             }
-            uDebug() << fileName << ": " << includeFile << " => " << it.value().first;
+            logDebug3("CppImport::feedTheModel(%1): %2 => %3", fileName, includeFile, it.value().first);
             if (ms_seenFiles.indexOf(includeFile) == -1)
                 ms_seenFiles.append(includeFile);
             feedTheModel(includeFile);
@@ -89,7 +92,7 @@ void CppImport::feedTheModel(const QString& fileName)
     }
     ParsedFilePointer ast = ms_driver->translationUnit(fileName);
     if (!ast) {
-        uError() << fileName << " not found in list of parsed files";
+        logError1("CppImport::feedTheModel: %1 not found in list of parsed files", fileName);
         return;
     }
     ms_seenFiles.append(fileName);
@@ -152,7 +155,7 @@ bool CppImport::parseFile(const QString& fileName)
         QString item = QString::fromLatin1("%1:%2:%3: %4: %5")
                 .arg(problem.fileName()).arg(problem.line()+1)
                 .arg(problem.column()).arg(level).arg(problem.text());
-        UMLApp::app()->logWindow()->addItem(item);
+        UMLApp::app()->log(item);
     }
     if (!result)
         return false;
