@@ -1,6 +1,7 @@
 /*
     SPDX-FileCopyrightText: 2011 Andi Fischer <andi.fischer@hispeed.ch>
     SPDX-FileCopyrightText: 2012 Ralf Habacker <ralf.habacker@freenet.de>
+    SPDX-FileCopyrightText: 2022 Oliver Kellogg <okellogg@users.sourceforge.net>
 
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -8,6 +9,11 @@
 #ifndef DEBUG_UTILS_H
 #define DEBUG_UTILS_H
 
+/*
+    This file shall only by #included by implementation files (.cpp),
+    not by header files (.h)
+*/
+
 #include <QtGlobal>
 
 #if QT_VERSION < 0x050000
@@ -48,11 +54,11 @@ Q_DECLARE_LOGGING_CATEGORY(UMBRELLO)
  *
  * - QObject based classes
  *
- *      DEBUG(DBG_SRC) << ...
+ *      DEBUG() << ...
  *
- * - other classes
+ * - other classes (Debug with given Name)
  *
- *      DEBUG("class name") << ...
+ *      DEBUG_N("class name") << ...
  */
 class Tracer : public QTreeWidget
 {
@@ -69,7 +75,9 @@ public:
     void enableAll();
     void disableAll();
 
-    static void registerClass(const QString& name, bool state=true, const QString &filePath=QString());
+    bool logToConsole();
+
+    static void registerClass(const char * name, bool state=true, const char * filePath=0);
 
 protected:
     void update(const QString &name);
@@ -92,9 +100,10 @@ private:
     typedef QMap<QString, MapEntry> MapType;
     typedef QMap<QString,Qt::CheckState> StateMap;
 
-    static Tracer* m_instance;
-    static MapType *m_classes;
-    static StateMap *m_states;
+    static Tracer* s_instance;
+    static MapType s_classes;
+    static StateMap s_states;
+    static bool s_logToConsole;
 
     explicit Tracer(QWidget *parent = 0);
 };
@@ -110,12 +119,25 @@ private:
 #define uWarning() kWarning(8060)
 #endif
 
+#ifndef DBG_SRC
 #define DBG_SRC  QString::fromLatin1(metaObject()->className())
+#endif
 #define DEBUG_SHOW_FILTER() Tracer::instance()->show()
-#define DEBUG(src)  if (Tracer::instance()->isEnabled(src)) uDebug()
-#define IS_DEBUG_ENABLED(src) Tracer::instance()->isEnabled(QString::fromLatin1(#src))
-#define DEBUG_REGISTER(src) class src##Tracer { public: src##Tracer() { Tracer::registerClass(QString::fromLatin1(#src), true, QLatin1String(__FILE__)); } }; static src##Tracer src##TracerGlobal;
-#define DEBUG_REGISTER_DISABLED(src) class src##Tracer { public: src##Tracer() { Tracer::registerClass(QString::fromLatin1(#src), false, QLatin1String(__FILE__)); } }; static src##Tracer src##TracerGlobal;
+#define DEBUG_N(latin1str)  if (Tracer::instance()->logToConsole() || Tracer::instance()->isEnabled(latin1str)) uDebug()
+#define DEBUG()       DEBUG_N(DBG_SRC)
+#define IS_DEBUG_ENABLED() Tracer::instance()->isEnabled(DBG_SRC)
+#define DEBUG_REGISTER(src)          \
+        class src##Tracer { \
+          public:           \
+            src##Tracer() { Tracer::registerClass(#src, true, __FILE__); } \
+        };                  \
+        static src##Tracer src##TracerGlobal;
+#define DEBUG_REGISTER_DISABLED(src) \
+        class src##Tracer { \
+          public:           \
+            src##Tracer() { Tracer::registerClass(#src, false, __FILE__); } \
+        };                  \
+        static src##Tracer src##TracerGlobal;
 
 #define uIgnoreZeroPointer(a) if (!a) { uDebug() << "zero pointer detected" << __FILE__ << __LINE__; continue; }
 
