@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2006-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2006-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -10,6 +10,7 @@
 #include "uml.h"
 #include "umldoc.h"
 #include "folder.h"
+#define DBG_SRC QLatin1String("Import_Rose")
 #include "debug_utils.h"
 #include "import_utils.h"
 #include "petalnode.h"
@@ -25,6 +26,8 @@
 #include <QStringList>
 #include <QTextStream>
 
+DEBUG_REGISTER(Import_Rose)
+
 namespace Import_Rose {
 
 /**
@@ -199,21 +202,21 @@ QString collectVerbatimText(QTextStream& stream)
         if (line.isEmpty() || line.startsWith(QLatin1Char(')')))
             break;
         if (line[0] != QLatin1Char('|')) {
-            uError() << loc() << "expecting '|' at start of verbatim text";
+            logError1("%1 expecting '|' at start of verbatim text", loc());
             return QString();
         } else {
             result += line.mid(1) + QLatin1Char('\n');
         }
     }
     if (line.isNull()) {
-        uError() << loc() << "premature EOF";
+        logError1("%1 premature EOF", loc());
         return QString();
     }
     if (! line.isEmpty()) {
         for (int i = 0; i < line.length(); ++i) {
             const QChar& clParenth = line[i];
             if (clParenth != QLatin1Char(')')) {
-                uError() << loc() << "expected ')', found: " << clParenth;
+                logError2("%1 expected ')', found: %2", loc(), clParenth);
                 return QString();
             }
             nClosures++;
@@ -261,7 +264,7 @@ QString extractValue(QStringList& l, QTextStream& stream)
     } else {
         result = shift(l);
         if (l.first() != QLatin1String(")")) {
-            uError() << loc() << "expecting closing parenthesis";
+            logError1("%1 expecting closing parenthesis", loc());
             return result;
         }
         l.pop_front();
@@ -284,7 +287,7 @@ PetalNode *readAttributes(QStringList initialArgs, QTextStream& stream)
 {
     methodName(QLatin1String("readAttributes"));
     if (initialArgs.count() == 0) {
-        uError() << loc() << "initialArgs is empty";
+        logError1("%1 initialArgs is empty", loc());
         return 0;
     }
     PetalNode::NodeType nt;
@@ -294,7 +297,7 @@ PetalNode *readAttributes(QStringList initialArgs, QTextStream& stream)
     else if (type == QLatin1String("list"))
         nt = PetalNode::nt_list;
     else {
-        uError() << loc() << "unknown node type " << type;
+        logError2("%1 unknown node type %2", loc(), type);
         return 0;
     }
     PetalNode *node = new PetalNode(nt);
@@ -313,7 +316,7 @@ PetalNode *readAttributes(QStringList initialArgs, QTextStream& stream)
         QString stringOrNodeOpener = shift(tokens);
         QString name;
         if (nt == PetalNode::nt_object && !stringOrNodeOpener.contains(QRegExp(QLatin1String("^[A-Za-z]")))) {
-            uError() << loc() << "unexpected line " << line;
+            logError2("%1 unexpected line %2", loc(), line);
             delete node;
             return 0;
         }
@@ -341,8 +344,7 @@ PetalNode *readAttributes(QStringList initialArgs, QTextStream& stream)
             attr.second = value;
             attrs.append(attr);
             if (tokens.count() && tokens.first() != QLatin1String(")")) {
-                uDebug() << loc()
-                    << "NYI - immediate list entry with more than one item";
+                logDebug1("%1 NYI - immediate list entry with more than one item", loc());
             }
             if (checkClosing(tokens))
                 break;
@@ -411,6 +413,7 @@ PetalNode *readAttributes(QStringList initialArgs, QTextStream& stream)
  */
 UMLPackage* loadFromMDL(QFile& file, UMLPackage *parentPkg /* = 0 */) 
 {
+    methodName(QLatin1String("loadFromMDL"));
     if (parentPkg == 0) {
         QString fName = file.fileName();
         int lastSlash = fName.lastIndexOf(QLatin1Char('/'));
@@ -441,7 +444,7 @@ UMLPackage* loadFromMDL(QFile& file, UMLPackage *parentPkg /* = 0 */)
                 if (a.size() == 2 && a[0] == QLatin1String("charSet")) {
                     const QString& charSet = a[1];
                     if (!charSet.contains(QRegExp(QLatin1String("^\\d+$")))) {
-                        uWarning() << "Unimplemented charSet " << charSet;
+                        logWarn2("%1 Unimplemented charSet %2", loc(), charSet);
                         if (finish)
                             break;
                         continue;
@@ -487,7 +490,7 @@ UMLPackage* loadFromMDL(QFile& file, UMLPackage *parentPkg /* = 0 */)
                         case 255:  // OEM (extended ASCII)
                             SETCODEC("windows-1252");
                         default:
-                            uWarning() << "Unimplemented charSet number" << charSetNum;
+                            logWarn2("%1 Unimplemented charSet number %2", loc(), charSetNum);
                     }
                 }
                 if (finish)
@@ -512,12 +515,9 @@ UMLPackage* loadFromMDL(QFile& file, UMLPackage *parentPkg /* = 0 */)
     if (root == 0)
         return 0;
 
-    if (progLang == Uml::ProgrammingLanguage::Reserved &&
-                    UMLApp::app()->generator() == nullptr) {
-        UMLApp::app()->setGenerator(Uml::ProgrammingLanguage::Cpp);
-    } else if (progLang != UMLApp::app()->activeLanguage()) {
-        uDebug() << "loadFromMDL: Setting active language to "
-                 << Uml::ProgrammingLanguage::toString(progLang);
+    if (progLang != UMLApp::app()->activeLanguage()) {
+        logDebug1("loadFromMDL: Setting active language to %1",
+                  Uml::ProgrammingLanguage::toString(progLang));
         UMLApp::app()->setGenerator(progLang);
     }
 
@@ -528,7 +528,7 @@ UMLPackage* loadFromMDL(QFile& file, UMLPackage *parentPkg /* = 0 */)
     }
 
     if (root->name() != QLatin1String("Design")) {
-        uError() << "expecting root name Design";
+        logError1("%1 expecting root name Design", loc());
         delete root;
         return 0;
     }
