@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #ifndef ASSOCIATIONLINE_H
@@ -134,8 +134,8 @@ public:
 
     void dumpPoints();
 
-    bool loadFromXMI1(QDomElement &qElement);
-    void saveToXMI1(QXmlStreamWriter& writer);
+    bool loadFromXMI(QDomElement &qElement);
+    void saveToXMI(QXmlStreamWriter& writer);
 
     QBrush brush() const;
     QPen pen() const;
@@ -193,7 +193,7 @@ private:
     static QPainterPath createBezierCurve(QVector<QPointF> points);
     static QPainterPath createOrthogonalPath(QVector<QPointF> points);
 
-    qreal              c1dx{0.0}, c1dy{0.0}, c2dx{0.0}, c2dy{0.0};
+    qreal              m_c1dx{0.0}, m_c1dy{0.0}, m_c2dx{0.0}, m_c2dy{0.0};
     static const qreal Delta;  ///< default delta for fuzzy recognition of points closer to point
     static const qreal SelectedPointDiameter;         ///< radius of circles drawn to show "selection"
     static const qreal SelfAssociationMinimumHeight;  ///< minimum height for self association's loop
